"""Hutch - Security Engineering Toolkit."""

__version__ = "0.2.0"
__title__ = "hutch-security"
__author__ = "HashiCorp Security (Security Engineering)"
__license__ = "Mozilla Public License 2.0"
__copyright__ = "Copyright 2022 HashiCorp, Inc."
